@@ -10,51 +10,45 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.06';
-$DATE = '2003/08/01';
+$VERSION = '0.07';
+$DATE = '2004/04/09';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.06 2003/08/01), 'revised 0.05'],
-    'MANIFEST' => [qw(0.06 2003/08/01), 'generated, replaces 0.05'],
-    'Makefile.PL' => [qw(0.06 2003/08/01), 'generated, replaces 0.05'],
-    'README' => [qw(0.06 2003/08/01), 'generated, replaces 0.05'],
-    'lib/Test/STDmaker.pm' => [qw(1.09 2003/08/01), 'revised 1.08'],
-    'lib/Test/STDType/Demo.pm' => [qw(1.07 2003/08/01), 'revised 1.06'],
-    'lib/Test/STDType/STD.pm' => [qw(1.07 2003/07/05), 'unchanged'],
-    'lib/Test/STDType/Verify.pm' => [qw(1.07 2003/08/01), 'revised 1.06'],
-    'lib/Test/STD/Check.pm' => [qw(1.07 2003/08/01), 'revised 1.06'],
-    'lib/Test/STD/FileGen.pm' => [qw(1.06 2003/07/05), 'unchanged'],
-    'lib/Test/STD/STD2167.pm' => [qw(1.04 2003/07/05), 'unchanged'],
-    'lib/Test/STD/STDgen.pm' => [qw(1.04 2003/07/05), 'unchanged'],
-    't/Test/STDmaker/FileGenI.pm' => [qw(1.02 2003/06/14), 'unchanged'],
-    't/Test/STDmaker/STDmaker.d' => [qw(0.07 2003/08/01), 'revised 0.06'],
-    't/Test/STDmaker/STDmaker.pm' => [qw(0.06 2003/08/01), 'revised 0.05'],
-    't/Test/STDmaker/STDmaker.t' => [qw(0.07 2003/08/01), 'revised 0.06'],
-    't/Test/STDmaker/temp0.pl' => [qw(0.06 2003/08/01), 'new'],
-    't/Test/STDmaker/tg0.pm' => [qw(0.02 2003/06/14), 'unchanged'],
-    't/Test/STDmaker/tg2n.pm' => [qw(0.02 2003/08/01), 'new'],
-    't/Test/STDmaker/tg2s.pm' => [qw(0.02 2003/08/01), 'new'],
-    't/Test/STDmaker/tgA0.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgA2.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgA2An.txt' => [qw(0.06 2003/08/01), 'new'],
-    't/Test/STDmaker/tgA2As.txt' => [qw(0.06 2003/08/01), 'new'],
-    't/Test/STDmaker/tgA2B.txt' => [qw(0.05 2003/08/01), 'revised 0.04'],
-    't/Test/STDmaker/tgA2C.txt' => [qw(0.06 2003/08/01), 'revised 0.05'],
-    't/Test/STDmaker/tgA2D.txt' => [qw(0.03 2003/08/01), 'revised 0.02'],
-    't/Test/STDmaker/tgB0n.pm' => [qw(0.01 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgB0s.pm' => [qw(0.01 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgB2n.pm' => [qw(0.02 2003/08/01), 'revised 0.01'],
-    't/Test/STDmaker/tgB2n.txt' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgB2s.pm' => [qw(0.01 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgB2s.txt' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgC0.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/tgC2.pm' => [qw(0.02 2003/06/21), 'unchanged'],
-    't/Test/STDmaker/lib/Test.pm' => [qw(1.24 2003/08/01), 'new'],
-    'bin/tmake.pl' => [qw(1.05 2003/08/01), 'revised 1.04'],
-    'tlib/Text/Scrub.pm' => [qw(1.09 2003/08/01), 'new'],
-    'tlib/Test/Tech.pm' => [qw(1.12 2003/08/01), 'new'],
+    'lib/Docs/Site_SVD/Test_STDmaker.pm' => [qw(0.07 2004/04/09), 'revised 0.06'],
+    'MANIFEST' => [qw(0.07 2004/04/09), 'generated, replaces 0.06'],
+    'Makefile.PL' => [qw(0.07 2004/04/09), 'generated, replaces 0.06'],
+    'README' => [qw(0.07 2004/04/09), 'generated, replaces 0.06'],
+    'lib/Test/STDmaker.pm' => [qw(1.1 2004/04/09), 'revised 1.09'],
+    'lib/Test/STDType/Demo.pm' => [qw(1.08 2004/04/09), 'revised 1.07'],
+    'lib/Test/STDType/STD.pm' => [qw(1.08 2004/04/09), 'revised 1.07'],
+    'lib/Test/STDType/Verify.pm' => [qw(1.08 2004/04/09), 'revised 1.07'],
+    'lib/Test/STD/Check.pm' => [qw(1.08 2004/04/09), 'revised 1.07'],
+    'lib/Test/STD/FileGen.pm' => [qw(1.07 2004/04/09), 'revised 1.06'],
+    'lib/Test/STD/STD2167.pm' => [qw(1.05 2004/04/09), 'revised 1.04'],
+    'lib/Test/STD/STDgen.pm' => [qw(1.05 2004/04/09), 'revised 1.04'],
+    't/Test/STDmaker/STDmaker.d' => [qw(0.08 2004/04/09), 'revised 0.07'],
+    't/Test/STDmaker/STDmaker.pm' => [qw(0.07 2004/04/09), 'revised 0.06'],
+    't/Test/STDmaker/STDmaker.t' => [qw(0.08 2004/04/09), 'revised 0.07'],
+    't/Test/STDmaker/tg0.pm' => [qw(0.03 2004/04/09), 'revised 0.02'],
+    't/Test/STDmaker/tg2.pm' => [qw(0.02 2004/04/09), 'new'],
+    't/Test/STDmaker/tgA0.pm' => [qw(0.03 2004/04/09), 'revised 0.02'],
+    't/Test/STDmaker/tgA2.pm' => [qw(0.03 2004/04/09), 'revised 0.02'],
+    't/Test/STDmaker/tgA2A.txt' => [qw(0.07 2004/04/09), 'new'],
+    't/Test/STDmaker/tgA2B.txt' => [qw(0.06 2004/04/09), 'revised 0.05'],
+    't/Test/STDmaker/tgA2C.txt' => [qw(0.07 2004/04/09), 'revised 0.06'],
+    't/Test/STDmaker/tgA2D.txt' => [qw(0.03 2003/08/01), 'unchanged'],
+    't/Test/STDmaker/tgB0.pm' => [qw(0.01 2004/04/09), 'new'],
+    't/Test/STDmaker/tgB2.pm' => [qw(0.01 2004/04/09), 'new'],
+    't/Test/STDmaker/tgB2.txt' => [qw(0.07 2004/04/09), 'new'],
+    't/Test/STDmaker/tgC0.pm' => [qw(0.03 2004/04/09), 'revised 0.02'],
+    't/Test/STDmaker/tgC2.pm' => [qw(0.03 2004/04/09), 'revised 0.02'],
+    'bin/tmake.pl' => [qw(1.05 2003/08/01), 'unchanged'],
+    't/Test/STDmaker/Text/Scrub.pm' => [qw(1.11 2004/04/09), 'new'],
+    't/Test/STDmaker/Test/Tech.pm' => [qw(1.17 2004/04/09), 'new'],
+    't/Test/STDmaker/Data/Secs2.pm' => [qw(1.15 2004/04/09), 'new'],
+    't/Test/STDmaker/File/TestPath.pm' => [qw(1.11 2004/04/09), 'new'],
 
 );
 
@@ -81,11 +75,11 @@ use vars qw(%INVENTORY);
 
  Test::STDmaker - Test Scripts, Demo Scripts and Software Test Description (STD) Automation
 
- Revision: E
+ Revision: F
 
- Version: 0.06
+ Version: 0.07
 
- Date: 2003/08/01
+ Date: 2004/04/09
 
  Prepared for: General Public 
 
@@ -214,7 +208,7 @@ The dependency of the program modules in the US DOD STD2167A bundle is as follow
 
 =head2 1.3 Document overview.
 
-This document releases Test::STDmaker version 0.06
+This document releases Test::STDmaker version 0.07
 providing description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -227,12 +221,14 @@ system file specification.
 
 =head2 3.1 Inventory of materials released.
 
-This document releases the file found
-at the following repository(s):
+This document releases the file 
 
-   http://www.softwarediamonds/packages/Test-STDmaker-0.06
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-STDmaker-0.06
+ Test-STDmaker-0.07.tar.gz
 
+found at the following repository(s):
+
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
 Restrictions regarding duplication and license provisions
 are as follows:
@@ -308,45 +304,39 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Test_STDmaker.pm                           0.06    2003/08/01 revised 0.05
- MANIFEST                                                     0.06    2003/08/01 generated, replaces 0.05
- Makefile.PL                                                  0.06    2003/08/01 generated, replaces 0.05
- README                                                       0.06    2003/08/01 generated, replaces 0.05
- lib/Test/STDmaker.pm                                         1.09    2003/08/01 revised 1.08
- lib/Test/STDType/Demo.pm                                     1.07    2003/08/01 revised 1.06
- lib/Test/STDType/STD.pm                                      1.07    2003/07/05 unchanged
- lib/Test/STDType/Verify.pm                                   1.07    2003/08/01 revised 1.06
- lib/Test/STD/Check.pm                                        1.07    2003/08/01 revised 1.06
- lib/Test/STD/FileGen.pm                                      1.06    2003/07/05 unchanged
- lib/Test/STD/STD2167.pm                                      1.04    2003/07/05 unchanged
- lib/Test/STD/STDgen.pm                                       1.04    2003/07/05 unchanged
- t/Test/STDmaker/FileGenI.pm                                  1.02    2003/06/14 unchanged
- t/Test/STDmaker/STDmaker.d                                   0.07    2003/08/01 revised 0.06
- t/Test/STDmaker/STDmaker.pm                                  0.06    2003/08/01 revised 0.05
- t/Test/STDmaker/STDmaker.t                                   0.07    2003/08/01 revised 0.06
- t/Test/STDmaker/temp0.pl                                     0.06    2003/08/01 new
- t/Test/STDmaker/tg0.pm                                       0.02    2003/06/14 unchanged
- t/Test/STDmaker/tg2n.pm                                      0.02    2003/08/01 new
- t/Test/STDmaker/tg2s.pm                                      0.02    2003/08/01 new
- t/Test/STDmaker/tgA0.pm                                      0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgA2.pm                                      0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgA2An.txt                                   0.06    2003/08/01 new
- t/Test/STDmaker/tgA2As.txt                                   0.06    2003/08/01 new
- t/Test/STDmaker/tgA2B.txt                                    0.05    2003/08/01 revised 0.04
- t/Test/STDmaker/tgA2C.txt                                    0.06    2003/08/01 revised 0.05
- t/Test/STDmaker/tgA2D.txt                                    0.03    2003/08/01 revised 0.02
- t/Test/STDmaker/tgB0n.pm                                     0.01    2003/06/21 unchanged
- t/Test/STDmaker/tgB0s.pm                                     0.01    2003/06/21 unchanged
- t/Test/STDmaker/tgB2n.pm                                     0.02    2003/08/01 revised 0.01
- t/Test/STDmaker/tgB2n.txt                                    0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgB2s.pm                                     0.01    2003/06/21 unchanged
- t/Test/STDmaker/tgB2s.txt                                    0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgC0.pm                                      0.02    2003/06/21 unchanged
- t/Test/STDmaker/tgC2.pm                                      0.02    2003/06/21 unchanged
- t/Test/STDmaker/lib/Test.pm                                  1.24    2003/08/01 new
- bin/tmake.pl                                                 1.05    2003/08/01 revised 1.04
- tlib/Text/Scrub.pm                                           1.09    2003/08/01 new
- tlib/Test/Tech.pm                                            1.12    2003/08/01 new
+ lib/Docs/Site_SVD/Test_STDmaker.pm                           0.07    2004/04/09 revised 0.06
+ MANIFEST                                                     0.07    2004/04/09 generated, replaces 0.06
+ Makefile.PL                                                  0.07    2004/04/09 generated, replaces 0.06
+ README                                                       0.07    2004/04/09 generated, replaces 0.06
+ lib/Test/STDmaker.pm                                         1.1     2004/04/09 revised 1.09
+ lib/Test/STDType/Demo.pm                                     1.08    2004/04/09 revised 1.07
+ lib/Test/STDType/STD.pm                                      1.08    2004/04/09 revised 1.07
+ lib/Test/STDType/Verify.pm                                   1.08    2004/04/09 revised 1.07
+ lib/Test/STD/Check.pm                                        1.08    2004/04/09 revised 1.07
+ lib/Test/STD/FileGen.pm                                      1.07    2004/04/09 revised 1.06
+ lib/Test/STD/STD2167.pm                                      1.05    2004/04/09 revised 1.04
+ lib/Test/STD/STDgen.pm                                       1.05    2004/04/09 revised 1.04
+ t/Test/STDmaker/STDmaker.d                                   0.08    2004/04/09 revised 0.07
+ t/Test/STDmaker/STDmaker.pm                                  0.07    2004/04/09 revised 0.06
+ t/Test/STDmaker/STDmaker.t                                   0.08    2004/04/09 revised 0.07
+ t/Test/STDmaker/tg0.pm                                       0.03    2004/04/09 revised 0.02
+ t/Test/STDmaker/tg2.pm                                       0.02    2004/04/09 new
+ t/Test/STDmaker/tgA0.pm                                      0.03    2004/04/09 revised 0.02
+ t/Test/STDmaker/tgA2.pm                                      0.03    2004/04/09 revised 0.02
+ t/Test/STDmaker/tgA2A.txt                                    0.07    2004/04/09 new
+ t/Test/STDmaker/tgA2B.txt                                    0.06    2004/04/09 revised 0.05
+ t/Test/STDmaker/tgA2C.txt                                    0.07    2004/04/09 revised 0.06
+ t/Test/STDmaker/tgA2D.txt                                    0.03    2003/08/01 unchanged
+ t/Test/STDmaker/tgB0.pm                                      0.01    2004/04/09 new
+ t/Test/STDmaker/tgB2.pm                                      0.01    2004/04/09 new
+ t/Test/STDmaker/tgB2.txt                                     0.07    2004/04/09 new
+ t/Test/STDmaker/tgC0.pm                                      0.03    2004/04/09 revised 0.02
+ t/Test/STDmaker/tgC2.pm                                      0.03    2004/04/09 revised 0.02
+ bin/tmake.pl                                                 1.05    2003/08/01 unchanged
+ t/Test/STDmaker/Text/Scrub.pm                                1.11    2004/04/09 new
+ t/Test/STDmaker/Test/Tech.pm                                 1.17    2004/04/09 new
+ t/Test/STDmaker/Data/Secs2.pm                                1.15    2004/04/09 new
+ t/Test/STDmaker/File/TestPath.pm                             1.11    2004/04/09 new
 
 
 =head2 3.3 Changes
@@ -450,6 +440,23 @@ The test of this module will precede immediately.
 The test support files in the tlib directory will vanish after
 the installtion.
 
+=item Test-STDmaker-0.07
+
+Change the location where of Test::STDmaker expects the test library from tlib
+to the the same directory as the test script. Eliminated the need for File::TestPath.
+which adds the tlib directory to the @INC directory of lists with the below
+Perl build-ins:
+
+ use FindBIN 
+ use lib $FindBin::Bin;
+
+Replace the obsoleted File::PM2File program module with File::Where.
+
+Eliminated detecting broken Perl where Data::Dumper treats arrays of number as
+strings on some Perl and numbers on others. 
+If something is broken, replace it with a fixed version in order to
+pass the tests for the Test::STDmaker program module.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -474,28 +481,45 @@ and installation support are as follows:
 
 =item Installation Instructions.
 
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
-   http://www.softwarediamonds/packages/Test-STDmaker-0.06
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Test-STDmaker-0.06
+  http://www.softwarediamonds/packages/
+  http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/
 
+Right click on 'Test-STDmaker-0.07.tar.gz' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip Test-STDmaker-0.07.tar.gz
+ tar -xf Test-STDmaker-0.07.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 
 =item Prerequistes.
 
  'File::AnySpec' => '1.1',
  'File::Data' => '1.1',
  'File::Package' => '1.1',
- 'File::PM2File' => '1.1',
+ 'File::Where' => '0.02',
  'File::SmartNL' => '1.1',
  'File::SubPM' => '1.1',
- 'File::TestPath' => '1.',
  'Text::Replace' => '1.08',
  'Text::Column' => '1.08',
  'DataPort::FileType::FormDB' => '0.03',
@@ -548,7 +572,7 @@ design requirements and to design requirements tests
 =item *
 
 Functional requirements are basically requirements important
-to the end-user and stated for the point of view of the
+to the end-user and stated from the point of view of the
 end-user.  
 Test coverage is not an issue. 
 However, when design requirements are added to the mix,
@@ -740,10 +764,10 @@ __DATA__
 DISTNAME: Test-STDmaker^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.06^
+VERSION : 0.07^
 FREEZE: 1^
-PREVIOUS_RELEASE: 0.05^
-REVISION: E^
+PREVIOUS_RELEASE: 0.06^
+REVISION: F^
 
 PREVIOUS_DISTNAME:  ^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -784,18 +808,19 @@ t/Test/STDmaker/*
 t/Test/STDmaker/lib/*
 t/Test/STDmaker/lib/Data/*
 bin/tmake.pl
-lib/Text/Scrub.pm => tlib/Text/Scrub.pm
-lib/Test/Tech.pm => tlib/Test/Tech.pm
+lib/Text/Scrub.pm => t/Test/STDmaker/Text/Scrub.pm
+lib/Test/Tech.pm => t/Test/STDmaker/Test/Tech.pm
+lib/Data/Secs2.pm => t/Test/STDmaker/Data/Secs2.pm
+lib/File/TestPath.pm => t/Test/STDmaker/File/TestPath.pm
 ^
 
 PREREQ_PM:
 'File::AnySpec' => '1.1',
 'File::Data' => '1.1',
 'File::Package' => '1.1',
-'File::PM2File' => '1.1',
+'File::Where' => '0.02',
 'File::SmartNL' => '1.1',
 'File::SubPM' => '1.1',
-'File::TestPath' => '1.',
 'Text::Replace' => '1.08',
 'Text::Column' => '1.08',
 'DataPort::FileType::FormDB' => '0.03',
@@ -1013,6 +1038,23 @@ The test of this module will precede immediately.
 The test support files in the tlib directory will vanish after
 the installtion.
 
+\=item Test-STDmaker-0.07
+
+Change the location where of Test::STDmaker expects the test library from tlib
+to the the same directory as the test script. Eliminated the need for File::TestPath.
+which adds the tlib directory to the @INC directory of lists with the below
+Perl build-ins:
+
+ use FindBIN 
+ use lib $FindBin::Bin;
+
+Replace the obsoleted File::PM2File program module with File::Where.
+
+Eliminated detecting broken Perl where Data::Dumper treats arrays of number as
+strings on some Perl and numbers on others. 
+If something is broken, replace it with a fixed version in order to
+pass the tests for the Test::STDmaker program module.
+
 \=back
 
 ^
@@ -1041,7 +1083,7 @@ design requirements and to design requirements tests
 \=item *
 
 Functional requirements are basically requirements important
-to the end-user and stated for the point of view of the
+to the end-user and stated from the point of view of the
 end-user.  
 Test coverage is not an issue. 
 However, when design requirements are added to the mix,
@@ -1114,16 +1156,35 @@ ANY WAY OUT OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 INSTALLATION:
-To installed the release file, use the CPAN module in the Perl release
+To installed the release file, use the CPAN module
+pr PPM module in the Perl release
 or the INSTALL.PL script at the following web site:
 
  http://packages.SoftwareDiamonds.com
 
 Follow the instructions for the the chosen installation software.
 
-The distribution file is at the following respositories:
+If all else fails, the file may be manually installed.
+Enter one of the following repositories in a web browser:
 
 ${REPOSITORY}
+
+Right click on '${DIST_FILE}' and download to a temporary
+installation directory.
+Enter the following where $make is 'nmake' for microsoft
+windows; otherwise 'make'.
+
+ gunzip ${BASE_DIST_FILE}.tar.${COMPRESS_SUFFIX}
+ tar -xf ${BASE_DIST_FILE}.tar
+ perl Makefile.PL
+ $make test
+ $make install
+
+On Microsoft operating system, nmake, tar, and gunzip 
+must be in the exeuction path. If tar and gunzip are
+not install, download and install unxutils from
+
+ http://packages.softwarediamonds.com
 ^
 
 SUPPORT:
