@@ -10,8 +10,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.06';
-$DATE = '2003/08/01';
+$VERSION = '0.07';
+$DATE = '2004/04/09';
 $FILE = __FILE__;
 
 ########
@@ -40,7 +40,7 @@ $FILE = __FILE__;
 
  Version: 
 
- Date: 2003/08/01
+ Date: 2004/04/09
 
  Prepared for: General Public 
 
@@ -98,15 +98,9 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      # redirect the TESTERR to STDOUT
      #
      my $restore_testerr = tech_config( 'Test.TESTERR', \*STDOUT );   
-     my $internal_number = tech_config('Internal_Number');
      my $fp = 'File::Package';
      my $snl = 'File::SmartNL';
      my $s = 'Text::Scrub';
-     my $tgB0_pm = ($internal_number eq 'string') ? 'tgB0s.pm' : 'tgB0n.pm';
-     my $tgB2_pm = ($internal_number eq 'string') ? 'tgB2s.pm' : 'tgB2n.pm';
-     my $tgB2_txt = ($internal_number eq 'string') ? 'tgB2s.txt' : 'tgB2n.txt';
-     my $tgA2A_txt = ($internal_number eq 'string') ? 'tgA2As.txt' : 'tgA2An.txt';
-     my $tg2_pm = ($internal_number eq 'string') ? 'tg2s.pm' : 'tg2n.pm';
      my $test_results;
      my $loaded = 0;
      my @outputs;
@@ -114,7 +108,6 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
  VO: ^
 
   C:
-     use File::Copy;
      @outputs = bsd_glob( 'tg*1.*' );
      unlink @outputs;
      #### 
@@ -181,10 +174,10 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
 =head2 ok: 4
 
  DO: ^
-  A: $snl->fin('tgB0n.pm')^
+  A: $snl->fin('tgB0.pm')^
 
   C:
-     copy $tgB0_pm, 'tgB1.pm';
+     copy 'tgB0.pm', 'tgB1.pm';
      $tmaker->tmake('STD', 'verify', {pm => 't::Test::STDmaker::tgB1'} );
  ^
 
@@ -196,8 +189,8 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
      L<Test::STDmaker/file_out option [1]>
  ^
   A: $s->scrub_date_version($snl->fin('tgB1.pm'))^
-  N: clean STD pm without a todo list^
-  E: $s->scrub_date_version($snl->fin($tgB2_pm))^
+  N: Clean STD pm without a todo list^
+  E: $s->scrub_date_version($snl->fin('tgB2.pm'))^
  ok: 4^
 
 =head2 ok: 5
@@ -209,7 +202,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
  ^
   A: $s->scrub_probe($s->scrub_file_line($test_results))^
   N: Generated and execute the test script^
-  E: $s->scrub_probe($s->scrub_file_line($snl->fin($tgB2_txt)))^
+  E: $s->scrub_probe($s->scrub_file_line($snl->fin('tgB2.txt')))^
  ok: 5^
 
 =head2 ok: 6
@@ -255,7 +248,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
  ^
   A: $test_results^
   N: Demonstration script^
-  E: $snl->fin($tgA2A_txt)^
+  E: $snl->fin('tgA2A.txt')^
  ok: 7^
 
 =head2 ok: 8
@@ -305,7 +298,7 @@ L<STD FormDB Test Description Fields|Test::STDmaker/STD FormDB Test Description
  ^
   A: $s->scrub_date_version($snl->fin('tg1.pm'))^
   N: Generate and replace a demonstration^
-  E: $s->scrub_date_version($snl->fin($tg2_pm))^
+  E: $s->scrub_date_version($snl->fin('tg2.pm'))^
  ok: 9^
 
 =head2 ok: 10
@@ -630,15 +623,9 @@ Verify: STDmaker.t^
     #
     my $restore_testerr = tech_config( 'Test.TESTERR', \*STDOUT );   
 
-    my $internal_number = tech_config('Internal_Number');
     my $fp = 'File::Package';
     my $snl = 'File::SmartNL';
     my $s = 'Text::Scrub';
-    my $tgB0_pm = ($internal_number eq 'string') ? 'tgB0s.pm' : 'tgB0n.pm';
-    my $tgB2_pm = ($internal_number eq 'string') ? 'tgB2s.pm' : 'tgB2n.pm';
-    my $tgB2_txt = ($internal_number eq 'string') ? 'tgB2s.txt' : 'tgB2n.txt';
-    my $tgA2A_txt = ($internal_number eq 'string') ? 'tgA2As.txt' : 'tgA2An.txt';
-    my $tg2_pm = ($internal_number eq 'string') ? 'tg2s.pm' : 'tg2n.pm';
 
     my $test_results;
     my $loaded = 0;
@@ -648,8 +635,6 @@ Verify: STDmaker.t^
 VO: ^
 
  C:
-    use File::Copy;
-
     @outputs = bsd_glob( 'tg*1.*' );
     unlink @outputs;
 
@@ -714,10 +699,10 @@ DO: ^
 ok: 3^
 
 DO: ^
- A: $snl->fin('tgB0n.pm')^
+ A: $snl->fin('tgB0.pm')^
 
  C:
-    copy $tgB0_pm, 'tgB1.pm';
+    copy 'tgB0.pm', 'tgB1.pm';
     $tmaker->tmake('STD', 'verify', {pm => 't::Test::STDmaker::tgB1'} );
 ^
 
@@ -731,8 +716,8 @@ DO: ^
 ^
 
  A: $s->scrub_date_version($snl->fin('tgB1.pm'))^
- N: clean STD pm without a todo list^
- E: $s->scrub_date_version($snl->fin($tgB2_pm))^
+ N: Clean STD pm without a todo list^
+ E: $s->scrub_date_version($snl->fin('tgB2.pm'))^
 ok: 4^
 
 
@@ -743,7 +728,7 @@ ok: 4^
 
  A: $s->scrub_probe($s->scrub_file_line($test_results))^
  N: Generated and execute the test script^
- E: $s->scrub_probe($s->scrub_file_line($snl->fin($tgB2_txt)))^
+ E: $s->scrub_probe($s->scrub_file_line($snl->fin('tgB2.txt')))^
 ok: 5^
 
 VO: ^
@@ -789,7 +774,7 @@ VO: ^
 
  A: $test_results^
  N: Demonstration script^
- E: $snl->fin($tgA2A_txt)^
+ E: $snl->fin('tgA2A.txt')^
 ok: 7^
 
 VO: ^
@@ -838,7 +823,7 @@ DO: ^
 
  A: $s->scrub_date_version($snl->fin('tg1.pm'))^
  N: Generate and replace a demonstration^
- E: $s->scrub_date_version($snl->fin($tg2_pm))^
+ E: $s->scrub_date_version($snl->fin('tg2.pm'))^
 ok: 9^
 
 
